==> lingotek_overrides-3.7.2.tar.gz: lingotek_overrides/src/Plugin/lingotek_overrides/FormField/Status.php <==
<?php

namespace Drupal\lingotek_overrides\Plugin\lingotek_overrides\FormField;

use Drupal\content_moderation\ModerationInformationInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityPublishedInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\TranslatableInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\lingotek_overrides\Plugin\lingotek_overrides\FormFieldBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\DependencyInjection\Exception\ServiceNotFoundException;

/**
 * Defines a Lingotek form-field plugin for an entity's publication status.
 *
 * @LingotekOverridesFormField(
 *   id = "lingotek_overrides_status",
 *   title = @Translation("Status"),
 *   weight = 950,
 *   form_ids = {
 *     "lingotek_management",
 *     "lingotek_entity_management",
 *   }
 * )
 */
class Status extends FormFieldBase {

  /**
   * The module_handler service.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * The content_moderation.moderation_information service.
   *
   * @var \Drupal\content_moderation\ModerationInformationInterface
   */
  protected $moderationInformation;

  /**
   * Status constructor.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity_type.manager service.
   * @param \Drupal\Core\Database\Connection $connection
   *   The database service.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface
   *   The module_handler service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    EntityTypeManagerInterface $entity_type_manager,
    Connection $connection,
    ModuleHandlerInterface $module_handler,
    ModerationInformationInterface $moderation_information = NULL
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $entity_type_manager, $connection);
    $this->moduleHandler = $module_handler;
    $this->moderationInformation = $moderation_information;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    try {
      $moderation_information = $container->get('content_moderation.moderation_information');
    }
    catch (ServiceNotFoundException $e) {
      $moderation_information = NULL;
    }

    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('database'),
      $container->get('module_handler'),
      $moderation_information
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getHeader($entity_type_id = NULL) {
    if (!$this->moderationInformation) {
      return $this->weight($this->getPluginDefinition()['title']);
    }

    return $this->weight($this->t('Current revision'));
  }

  /**
   * {@inheritdoc}
   */
  public function getData(EntityInterface $entity) {
    $statuses = [];

    if ($entity instanceof TranslatableInterface) {
      $languages = array_keys($entity->getTranslationLanguages());

      foreach ($languages as $language) {
        $translation = $entity->getTranslation($language);
        $statuses[$this->getStatus($translation)][] = $language;
      }
    }

    return $this->weight($this->buildStatuses($statuses));
  }


  /**
   * Gets an entity's status or moderation state.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *
   * @return string
   *   The label of the status or moderation state.
   */
  protected function getStatus(ContentEntityInterface $entity) {
    if ($entity instanceof EntityPublishedInterface) {
      if (!$this->moderationInformation) {
        return $entity->isPublished() ? $this->t('Published')->__toString() : $this->t('Unpublished')->__toString();
      }

      return $this->getModerationState($entity);
    }

    return '';
  }

  /**
   * Gets the revision's content moderation state, if available.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity revision.
   *
   * @return string|bool
   *   Returns the label of the moderation state, if available, otherwise FALSE.
   */
  protected function getModerationState(ContentEntityInterface $entity) {
    if ($this->moderationInformation && $this->moderationInformation->isModeratedEntity($entity)) {
      if ($state = $entity->moderation_state->value) {
        $workflow = $this->moderationInformation->getWorkflowForEntity($entity);
        return $workflow->getTypePlugin()->getState($state)->label();
      }
    }

    return FALSE;
  }

  /**
   * Builds the statuses' renderable array.
   *
   * @param array $statuses
   *   An array of language codes, keyed by publication status or moderation
   *   state.
   *
   * @return array
   *   The renderable array.
   */
  protected function buildStatuses(array $statuses) {
    if ($statuses) {
      $list['#theme'] = 'item_list';

      foreach ($statuses as $status => $langcodes) {
        if ($status) {
          $parameters = ['@status' => $status, '%langcodes' => implode(', ', $langcodes)];
          $list['#items'][] = $this->t('@status: %langcodes', $parameters);
        }
      }
    }

    return $list ?? [];
  }

}

==> lingotek_overrides-3.7.3.tar.gz: lingotek_overrides/src/Plugin/lingotek_overrides/FormField/Status.php <==
<?php

namespace Drupal\lingotek_overrides\Plugin\lingotek_overrides\FormField;

use Drupal\content_moderation\ModerationInformationInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityPublishedInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\TranslatableInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\lingotek_overrides\Plugin\lingotek_overrides\FormFieldBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\DependencyInjection\Exception\ServiceNotFoundException;

/**
 * Defines a Lingotek form-field plugin for an entity's publication status.
 *
 * @LingotekOverridesFormField(
 *   id = "lingotek_overrides_status",
 *   title = @Translation("Status"),
 *   weight = 950,
 *   form_ids = {
 *     "lingotek_management",
 *     "lingotek_entity_management",
 *   }
 * )
 */
class Status extends FormFieldBase {

  /**
   * The language_manager service.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * The module_handler service.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * The content_moderation.moderation_information service.
   *
   * @var \Drupal\content_moderation\ModerationInformationInterface
   */
  protected $moderationInformation;

  /**
   * Status constructor.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity_type.manager service.
   * @param \Drupal\Core\Database\Connection $connection
   *   The database service.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language_manager service.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module_handler service.
   * @param \Drupal\content_moderation\ModerationInformationInterface $moderation_information
   *   The content_moderation.moderation_information service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    EntityTypeManagerInterface $entity_type_manager,
    Connection $connection,
    LanguageManagerInterface $language_manager,
    ModuleHandlerInterface $module_handler,
    ModerationInformationInterface $moderation_information = NULL
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $entity_type_manager, $connection);
    $this->languageManager = $language_manager;
    $this->moduleHandler = $module_handler;
    $this->moderationInformation = $moderation_information;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    try {
      $moderation_information = $container->get('content_moderation.moderation_information');
    }
    catch (ServiceNotFoundException $e) {
      $moderation_information = NULL;
    }

    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('database'),
      $container->get('language_manager'),
      $container->get('module_handler'),
      $moderation_information
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getHeader($entity_type_id = NULL) {
    if (!$this->moderationInformation) {
      return $this->weight($this->getPluginDefinition()['title']);
    }

    return $this->weight($this->t('Current revision'));
  }

  /**
   * {@inheritdoc}
   */
  public function getData(EntityInterface $entity) {
    $statuses = [];

    if ($entity instanceof TranslatableInterface) {
      $languages = array_keys($entity->getTranslationLanguages());

      foreach ($languages as $language) {
        $translation = $entity->getTranslation($language);
        $statuses[$this->getStatus($translation)][] = $language;
      }
    }

    return $this->weight($this->buildStatuses($statuses));
  }

  /**
   * Gets an entity's status or moderation state.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity.
   *
   * @return string
   *   The label of the status or moderation state.
   */
  protected function getStatus(ContentEntityInterface $entity) {
    if ($entity instanceof EntityPublishedInterface) {
      if (!$this->moderationInformation) {
        return $entity->isPublished() ? $this->t('Published')->__toString() : $this->t('Unpublished')->__toString();
      }

      return $this->getModerationState($entity);
    }

    return '';
  }

  /**
   * Gets the revision's content moderation state, if available.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity revision.
   *
   * @return string|bool
   *   Returns the label of the moderation state, if available, otherwise FALSE.
   */
  protected function getModerationState(ContentEntityInterface $entity) {
    if ($this->moderationInformation && $this->moderationInformation->isModeratedEntity($entity)) {
      if ($state = $entity->moderation_state->value) {
        $workflow = $this->moderationInformation->getWorkflowForEntity($entity);
        return $workflow->getTypePlugin()->getState($state)->label();
      }
    }

    return FALSE;
  }

  /**
   * Builds the statuses' renderable array.
   *
   * @param array $statuses
   *   An array of language codes, keyed by publication status or moderation
   *   state.
   *
   * @return array
   *   The renderable array.
   */
  protected function buildStatuses(array $statuses) {
    if ($statuses) {
      $list['#theme'] = 'item_list';

      foreach ($statuses as $status => $langcodes) {
        if ($status) {
          $parameters = ['@status' => $status, '%langcodes' => implode(', ', $langcodes)];
          $list['#items'][] = $this->t('@status: %langcodes', $parameters);
        }
      }
    }

    return $list ?? [];
  }

}
